"""
Version information.
"""

# the major version
pyosmium_major = '2.14'
# current release (Pip version)
pyosmium_release = '2.14.0'

# libosmium version shipped with the Pip release
libosmium_version = '2.14.0'
# protozero version shipped with the Pip release
protozero_version = '1.6.2'
